@@ -29,7 +29,6 @@
 #include <QDialog>
 #include <QAction>
 #include <QEvent>
-#include <QProcess>
 
 namespace Ui
 {
@@ -45,14 +44,16 @@ class MainWindow : public QDialog
 {
     Q_OBJECT
 
-protected:
-    QProcess *proc {};
-
 public:
     explicit MainWindow(const QCommandLineParser &arg_parser, QWidget *parent = nullptr);
     ~MainWindow();
 
-    Result runCmd(const QString &cmd);
+    Result run(const char *program, const QStringList &args = QStringList(),
+        const QString *input = nullptr);
+    inline Result shell(const QString &cmd, const QString *input = nullptr)
+    {
+        return run("/bin/bash", {"-c", cmd}, input);
+    }
 
     void setup();
 
@@ -71,9 +72,10 @@ private:
     void lockGUI(bool lock);
     void forumcopy();
     void plaincopy();
+    void showSavedMessage(const QString &filename, const QString &errmsg);
     QString systeminfo();
     QString apthistory();
-    QString readlog(const QString &logfile);
+    QString readfile(const QString &path, bool escalate = true);
     void buildInfoList();
     void listSelectAll();
     void listSelectDefault();
